diff --git a/modules/gui/qt4/components/interface_widgets.cpp b/modules/gui/qt4/components/interface_widgets.cpp
index 207699e..a740f98 100644
--- a/modules/gui/qt4/components/interface_widgets.cpp
+++ b/modules/gui/qt4/components/interface_widgets.cpp
@@ -934,10 +934,19 @@ FullscreenControllerWidget::FullscreenControllerWidget( intf_thread_t *_p_i,
     fscHidden = true;
     show();
     #endif
+
+    /* it is fine to know, when new-vout is created, because it means
+       old callbacks were dropped and we need to register them again
+       We have variable for it with pointer to new vout,
+       set in vout_intf.c by vout_IntfInit() */
+    var_AddCallback( p_intf->p_libvlc, "new-vout", newVoutCallback, this );
+    p_last_vout = NULL;
 }
 
 FullscreenControllerWidget::~FullscreenControllerWidget()
 {
+    if( p_last_vout )
+        vlc_object_release( p_last_vout );
 }
 
 /**
@@ -1122,10 +1131,18 @@ void FullscreenControllerWidget::keyPressEvent( QKeyEvent *event )
 /**
  * It is called when video start
  */
-void FullscreenControllerWidget::regFullscreenCallback( vout_thread_t *p_vout )
+void FullscreenControllerWidget::regFullscreenCallback( vout_thread_t *p_vout,
+                                                        vout_thread_t *p_old_vout )
 {
+    p_last_vout = p_vout; /* for releasing in desctructor */
+    if ( p_old_vout )
+    {
+        var_DelCallback( p_old_vout, "fullscreen", regMouseMoveCallback, this );
+        vlc_object_release( p_old_vout );
+    }
     if ( p_vout )
     {
+        vlc_object_yield( p_vout );
         var_AddCallback( p_vout, "fullscreen", regMouseMoveCallback, this );
     }
 }
@@ -1141,6 +1158,20 @@ void FullscreenControllerWidget::unregFullscreenCallback()
 }
 
 /**
+ * Call when new vout is created
+ */
+static int newVoutCallback( vlc_object_t *vlc_object, const char *variable,
+                            vlc_value_t old_val, vlc_value_t new_val,
+                            void *data )
+{
+    FullscreenControllerWidget *p_fs = ( FullscreenControllerWidget * ) data;
+    p_fs->regFullscreenCallback( ( vout_thread_t * ) new_val.p_object,
+                                 ( vout_thread_t * ) old_val.p_object );
+
+    return VLC_SUCCESS;
+}
+
+/**
  * Register and unregister callback for mouse moving
  */
 static int regMouseMoveCallback( vlc_object_t *vlc_object, const char *variable,
diff --git a/modules/gui/qt4/components/interface_widgets.hpp b/modules/gui/qt4/components/interface_widgets.hpp
index 762ae5c..328ca83 100644
--- a/modules/gui/qt4/components/interface_widgets.hpp
+++ b/modules/gui/qt4/components/interface_widgets.hpp
@@ -236,6 +236,9 @@ signals:
  * Fullscreen controller
  ***********************************/
 
+static int newVoutCallback( vlc_object_t *vlc_object, const char *variable, vlc_value_t old_val,
+    vlc_value_t new_val, void *data );
+
 static int showFullscreenControllCallback(vlc_object_t *vlc_object, const char *variable, vlc_value_t old_val,
     vlc_value_t new_val, void *data);
 
@@ -251,7 +254,7 @@ public:
 
     void setHideTimeout( int hideTimeout ) { i_hideTimeout = hideTimeout; }
     void setIsFullscreen( bool isFS ) { b_isFullscreen = isFS; }
-    void regFullscreenCallback( vout_thread_t *p_vout );
+    void regFullscreenCallback( vout_thread_t *p_vout, vout_thread_t *p_old_vout );
 
     bool isFSCHidden();
 
@@ -284,6 +287,7 @@ private:
     int i_hideTimeout;  /* FSC hiding timeout, same as mouse hiding timeout */
     bool b_mouseIsOver;
     bool b_isFullscreen;
+    vout_thread_t *p_last_vout;
 
 #ifdef WIN32TRICK
     bool fscHidden;
diff --git a/src/libvlc.c b/src/libvlc.c
index f68221f..1ca52f4 100644
--- a/src/libvlc.c
+++ b/src/libvlc.c
@@ -913,6 +913,9 @@ int libvlc_InternalInit( libvlc_int_t *p_libvlc, int i_argc,
 
     var_Create( p_libvlc, "intf-popupmenu", VLC_VAR_BOOL );
 
+    /* For initialization of FS controller in qt */
+    var_Create( p_libvlc, "new-vout", VLC_VAR_ADDRESS );
+
     /*
      * Get input filenames given as commandline arguments
      */
diff --git a/src/video_output/video_output.c b/src/video_output/video_output.c
diff --git a/src/video_output/vout_intf.c b/src/video_output/vout_intf.c
index 78a3c63..baa91f7 100644
--- a/src/video_output/vout_intf.c
+++ b/src/video_output/vout_intf.c
@@ -429,6 +429,10 @@ void vout_IntfInit( vout_thread_t *p_vout )
 
     var_Create( p_vout, "intf-change", VLC_VAR_BOOL );
     var_SetBool( p_vout, "intf-change", true );
+
+    vlc_value_t value;
+    value.p_object = ( vlc_object_t * ) p_vout;
+    var_Set( p_vout->p_libvlc, "new-vout", value );
 }
 
 /*****************************************************************************
